@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util;
 
-our $DATE = '2015-07-30'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -192,7 +192,7 @@ Perinci::CmdLine::Util - Utility routines related to Perinci::CmdLine
 
 =head1 VERSION
 
-This document describes version 0.07 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2015-07-30.
+This document describes version 0.08 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -203,9 +203,8 @@ This document describes version 0.07 of Perinci::CmdLine::Util (from Perl distri
 
 =head2 detect_perinci_cmdline_script(%args) -> [status, msg, result, meta]
 
-{en_US Detect whether a file is a Perinci::CmdLine-based CLI script}.
+Detect whether a file is a Perinci::CmdLine-based CLI script.
 
-{en_US 
 The criteria are:
 
 =over
@@ -219,7 +218,6 @@ bit set;
 
 =item * either: must be perl script (shebang line contains 'perl') and must contain
 something like C<use Perinci::CmdLine>;
-}
 
 =back
 
@@ -229,23 +227,19 @@ Arguments ('*' denotes required arguments):
 
 =item * B<filename> => I<str>
 
-{en_US Path to file to be checked}.
+Path to file to be checked.
 
-{en_US 
 Either C<filename> or C<string> must be specified.
-}
 
 =item * B<include_noexec> => I<bool> (default: 1)
 
-{en_US Include scripts that do not have +x mode bit set}.
+Include scripts that do not have +x mode bit set.
 
 =item * B<string> => I<buf>
 
-{en_US Path to file to be checked}.
+Path to file to be checked.
 
-{en_US 
 Either C<file> or C<string> must be specified.
-}
 
 =back
 
